==> openshift-model-operatorhub-4.11.1-sources.jar: annotations/io/fabric8/openshift/api/model/operatorhub/v1alpha1/InstallPlanFluent.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.StringBuffer;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface InstallPlanFluent<A extends InstallPlanFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ObjectMeta getMetadata();
    public ObjectMeta buildMetadata();
    public A withMetadata(ObjectMeta metadata);
    public Boolean hasMetadata();
    public InstallPlanFluent.MetadataNested<A> withNewMetadata();
    public InstallPlanFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
    public InstallPlanFluent.MetadataNested<A> editMetadata();
    public InstallPlanFluent.MetadataNested<A> editOrNewMetadata();
    public InstallPlanFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@Deprecated public InstallPlanSpec getSpec();
    public InstallPlanSpec buildSpec();
    public A withSpec(InstallPlanSpec spec);
    public Boolean hasSpec();
    public InstallPlanFluent.SpecNested<A> withNewSpec();
    public InstallPlanFluent.SpecNested<A> withNewSpecLike(InstallPlanSpec item);
    public InstallPlanFluent.SpecNested<A> editSpec();
    public InstallPlanFluent.SpecNested<A> editOrNewSpec();
    public InstallPlanFluent.SpecNested<A> editOrNewSpecLike(InstallPlanSpec item);
    
/**
 * This method has been deprecated, please use method buildStatus instead.
 * @return The buildable object.
 */
@Deprecated public InstallPlanStatus getStatus();
    public InstallPlanStatus buildStatus();
    public A withStatus(InstallPlanStatus status);
    public Boolean hasStatus();
    public InstallPlanFluent.StatusNested<A> withNewStatus();
    public InstallPlanFluent.StatusNested<A> withNewStatusLike(InstallPlanStatus item);
    public InstallPlanFluent.StatusNested<A> editStatus();
    public InstallPlanFluent.StatusNested<A> editOrNewStatus();
    public InstallPlanFluent.StatusNested<A> editOrNewStatusLike(InstallPlanStatus item);

    public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ObjectMetaFluent<InstallPlanFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}
    public interface SpecNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,InstallPlanSpecFluent<InstallPlanFluent.SpecNested<N>>{

        
    public N and();    public N endSpec();
}
    public interface StatusNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,InstallPlanStatusFluent<InstallPlanFluent.StatusNested<N>>{

        
    public N and();    public N endStatus();
}


}

==> openshift-model-operatorhub-5.3.0-sources.jar: annotations/io/fabric8/openshift/api/model/operatorhub/v1alpha1/InstallPlanFluent.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.StringBuffer;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface InstallPlanFluent<A extends InstallPlanFluent<A>> extends Fluent<A> {


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(int[] arg1,int arg2,int arg3);
    public A withNewApiVersion(char[] arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A withNewApiVersion(byte[] arg1,int arg2);
    public A withNewApiVersion(byte[] arg1);
    public A withNewApiVersion(char[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewApiVersion(String arg1);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(int[] arg1,int arg2,int arg3);
    public A withNewKind(char[] arg1);
    public A withNewKind(StringBuffer arg1);
    public A withNewKind(byte[] arg1,int arg2);
    public A withNewKind(byte[] arg1);
    public A withNewKind(char[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewKind(String arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ObjectMeta getMetadata();
    public ObjectMeta buildMetadata();
    public A withMetadata(ObjectMeta metadata);
    public Boolean hasMetadata();
    public InstallPlanFluent.MetadataNested<A> withNewMetadata();
    public InstallPlanFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
    public InstallPlanFluent.MetadataNested<A> editMetadata();
    public InstallPlanFluent.MetadataNested<A> editOrNewMetadata();
    public InstallPlanFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@Deprecated public InstallPlanSpec getSpec();
    public InstallPlanSpec buildSpec();
    public A withSpec(InstallPlanSpec spec);
    public Boolean hasSpec();
    public InstallPlanFluent.SpecNested<A> withNewSpec();
    public InstallPlanFluent.SpecNested<A> withNewSpecLike(InstallPlanSpec item);
    public InstallPlanFluent.SpecNested<A> editSpec();
    public InstallPlanFluent.SpecNested<A> editOrNewSpec();
    public InstallPlanFluent.SpecNested<A> editOrNewSpecLike(InstallPlanSpec item);
    
/**
 * This method has been deprecated, please use method buildStatus instead.
 * @return The buildable object.
 */
@Deprecated public InstallPlanStatus getStatus();
    public InstallPlanStatus buildStatus();
    public A withStatus(InstallPlanStatus status);
    public Boolean hasStatus();
    public InstallPlanFluent.StatusNested<A> withNewStatus();
    public InstallPlanFluent.StatusNested<A> withNewStatusLike(InstallPlanStatus item);
    public InstallPlanFluent.StatusNested<A> editStatus();
    public InstallPlanFluent.StatusNested<A> editOrNewStatus();
    public InstallPlanFluent.StatusNested<A> editOrNewStatusLike(InstallPlanStatus item);
    public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ObjectMetaFluent<InstallPlanFluent.MetadataNested<N>> {

            public N and();
            public N endMetadata();    }


    public interface SpecNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,InstallPlanSpecFluent<InstallPlanFluent.SpecNested<N>> {

            public N and();
            public N endSpec();    }


    public interface StatusNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,InstallPlanStatusFluent<InstallPlanFluent.StatusNested<N>> {

            public N and();
            public N endStatus();    }


}
